@@ -149,7 +149,7 @@ class FieldBase(abc.ABC, metaclass=clu.abstract.Slotted):
             if value is not None:
                 value = self.extractor(value)
         except (TypeError, ValueError, ValidationError) as exc:
-            raise ValidationError(f"Extraction failue in “{self.name}”: {exc}")
+            raise ValidationError(f"Extraction failue in “{self.name}”") from exc
         
         if not (value is None and self.allow_none):
             if not self.validator(value):
@@ -169,7 +169,7 @@ class FieldBase(abc.ABC, metaclass=clu.abstract.Slotted):
     
     def __repr__(self):
         return stringify(self,
-               slots_for(self),
+               slots_for(type(self)),
                try_callables=False)
     
     def __json__(self, **kwargs):
@@ -201,7 +201,7 @@ class SchemaField(FieldBase):
                 value = self.cls(**value)
             return super(SchemaField, self).__set__(instance, value)
         except ValidationError as exc:
-            raise ValidationError(f"Validation failure in {nameof(type(self))}: {exc}")
+            raise ValidationError(f"Validation failure in {nameof(type(self))}") from exc
 
 @export
 class StringField(FieldBase):
@@ -530,7 +530,7 @@ class ListField(FieldBase):
                 try:
                     thing = self.value.__set__(schema, thing)
                 except ValidationError as exc:
-                    raise ValidationError(f'Validation failure in {self.name}: {exc}')
+                    raise ValidationError(f'Validation failure in {self.name}') from exc
                 newvalue.append(thing)
             value = newvalue
         
@@ -571,7 +571,7 @@ class TupleField(FieldBase):
                 try:
                     thing = self.value.__set__(schema, thing)
                 except ValidationError as exc:
-                    raise ValidationError(f'Validation failure in {self.name}: {exc}')
+                    raise ValidationError(f'Validation failure in {self.name}') from exc
                 newvalue += tuplize(thing)
             value = tuple(newvalue)
         
@@ -612,7 +612,7 @@ class SetField(FieldBase):
                 try:
                     thing = self.value.__set__(schema, thing)
                 except ValidationError as exc:
-                    raise ValidationError(f'Validation failure in {self.name}: {exc}')
+                    raise ValidationError(f'Validation failure in {self.name}') from exc
                 newvalue.add(thing)
             value = newvalue
         
@@ -653,7 +653,7 @@ class FrozenSetField(FieldBase):
                 try:
                     thing = self.value.__set__(schema, thing)
                 except ValidationError as exc:
-                    raise ValidationError(f'Validation failure in {self.name}: {exc}')
+                    raise ValidationError(f'Validation failure in {self.name}') from exc
                 newvalue.add(thing)
             value = frozenset(newvalue)
         
@@ -701,12 +701,12 @@ class DictField(FieldBase):
                 try:
                     k = self.key.__set__(schema, k)
                 except ValidationError as exc:
-                    raise ValidationError(f'Validation failure in {self.name} [key]: {exc}')
+                    raise ValidationError(f'Validation failure in {self.name} [key]') from exc
             if self.value is not None:
                 try:
                     v = self.value.__set__(schema, v)
                 except ValidationError as exc:
-                    raise ValidationError(f'Validation failure in {self.name} [value]: {exc}')
+                    raise ValidationError(f'Validation failure in {self.name} [value]') from exc
             newvalue[k] = v
         return super(DictField, self).__set__(instance, newvalue)
 
@@ -775,7 +775,7 @@ class NamespacedFieldManager(object):
             No parameters are accepted.
         """
         self.namespace_stack = []
-        self.__qualname__ = self.__name__ = 'fields'
+        self.__qualname__ = self.__name__ = 'fields' # TODO: qualname updates
         self.__file__ = __file__
     
     def push(self, namespace):
