@@ -190,3 +190,141 @@ Hesitating then no longer? Sir, said I, or Madam, truly your forgiveness I
 implore; But the fact is I was napping, and so gently you came rapping, And so
 faintly you came tapping, tapping at my chamber door?
 """
+
+# Python version figlet banners – using the figlet “Colossal” typeface:
+banners = {}
+
+banners['python3.x'] = """
+                  888    888                         .d8888b.                
+                  888    888                        d88P  Y88b               
+                  888    888                             .d88P               
+88888b.  888  888 888888 88888b.   .d88b.  88888b.      8888"      888  888  
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b      "Y8b.     `Y8bd8P'  
+888  888 888  888 888    888  888 888  888 888  888 888    888       X88K    
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 Y88b  d88P d8b .d8""8b.  
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888  "Y8888P"  Y8P 888  888  
+888           888                                                            
+888      Y8b d88P                                                            
+888       "Y88P"                                                             
+                                                                             
+"""
+
+banners['python3.8'] = """
+                  888    888                         .d8888b.       .d8888b.  
+                  888    888                        d88P  Y88b     d88P  Y88b 
+                  888    888                             .d88P     Y88b .d88P 
+88888b.  888  888 888888 88888b.   .d88b.  88888b.      8888"       "888888"  
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b      "Y8b.     .d8Y""Y8b. 
+888  888 888  888 888    888  888 888  888 888  888 888    888     888    888 
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 Y88b  d88P d8b Y88b  d88P 
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888  "Y8888P"  Y8P  "Y8888P"  
+888           888                                                             
+888      Y8b d88P                                                             
+888       "Y88P"                                                              
+                                                                              
+"""
+
+banners['python3.7'] = """
+                  888    888                         .d8888b.      8888888888 
+                  888    888                        d88P  Y88b           d88P 
+                  888    888                             .d88P          d88P  
+88888b.  888  888 888888 88888b.   .d88b.  88888b.      8888"          d88P   
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b      "Y8b.      88888888  
+888  888 888  888 888    888  888 888  888 888  888 888    888       d88P     
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 Y88b  d88P d8b  d88P      
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888  "Y8888P"  Y8P d88P       
+888           888                                                             
+888      Y8b d88P                                                             
+888       "Y88P"                                                              
+                                                                              
+"""
+
+banners['python2.7'] = """
+                  888    888                         .d8888b.      8888888888 
+                  888    888                        d88P  Y88b           d88P 
+                  888    888                               888          d88P  
+88888b.  888  888 888888 88888b.   .d88b.  88888b.       .d88P         d88P   
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b  .od888P"       88888888  
+888  888 888  888 888    888  888 888  888 888  888 d88P"            d88P     
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 888"       d8b  d88P      
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888 888888888  Y8P d88P       
+888           888                                                             
+888      Y8b d88P                                                             
+888       "Y88P"                                                              
+                                                                              
+"""
+
+banners['pypy3.x'] = """
+                                     .d8888b.                                 
+                                    d88P  Y88b                                
+                                         .d88P                                
+88888b.  888  888 88888b.  888  888     8888"      888  888                   
+888 "88b 888  888 888 "88b 888  888      "Y8b.     `Y8bd8P'                   
+888  888 888  888 888  888 888  888 888    888       X88K                     
+888 d88P Y88b 888 888 d88P Y88b 888 Y88b  d88P d8b .d8""8b.                   
+88888P"   "Y88888 88888P"   "Y88888  "Y8888P"  Y8P 888  888                   
+888           888 888           888                                           
+888      Y8b d88P 888      Y8b d88P                                           
+888       "Y88P"  888       "Y88P"                                            
+                                                                              
+"""
+
+banners['pypy3.8'] = """
+                                     .d8888b.       .d8888b.                  
+                                    d88P  Y88b     d88P  Y88b                 
+                                         .d88P     Y88b .d88P                 
+88888b.  888  888 88888b.  888  888     8888"       "888888"                  
+888 "88b 888  888 888 "88b 888  888      "Y8b.     .d8Y""Y8b.                 
+888  888 888  888 888  888 888  888 888    888     888    888                 
+888 d88P Y88b 888 888 d88P Y88b 888 Y88b  d88P d8b Y88b  d88P                 
+88888P"   "Y88888 88888P"   "Y88888  "Y8888P"  Y8P  "Y8888P"                  
+888           888 888           888                                           
+888      Y8b d88P 888      Y8b d88P                                           
+888       "Y88P"  888       "Y88P"                                            
+                                                                              
+"""
+
+banners['pypy3.7'] = """
+                                     .d8888b.      8888888888                 
+                                    d88P  Y88b           d88P                 
+                                         .d88P          d88P                  
+88888b.  888  888 88888b.  888  888     8888"          d88P                   
+888 "88b 888  888 888 "88b 888  888      "Y8b.      88888888                  
+888  888 888  888 888  888 888  888 888    888       d88P                     
+888 d88P Y88b 888 888 d88P Y88b 888 Y88b  d88P d8b  d88P                      
+88888P"   "Y88888 88888P"   "Y88888  "Y8888P"  Y8P d88P                       
+888           888 888           888                                           
+888      Y8b d88P 888      Y8b d88P                                           
+888       "Y88P"  888       "Y88P"                                            
+                                                                              
+"""
+
+banners['pypy3.6'] = """
+                                     .d8888b.       .d8888b.                  
+                                    d88P  Y88b     d88P  Y88b                 
+                                         .d88P     888                        
+88888b.  888  888 88888b.  888  888     8888"      888d888b.                  
+888 "88b 888  888 888 "88b 888  888      "Y8b.     888P "Y88b                 
+888  888 888  888 888  888 888  888 888    888     888    888                 
+888 d88P Y88b 888 888 d88P Y88b 888 Y88b  d88P d8b Y88b  d88P                 
+88888P"   "Y88888 88888P"   "Y88888  "Y8888P"  Y8P  "Y8888P"                  
+888           888 888           888                                           
+888      Y8b d88P 888      Y8b d88P                                           
+888       "Y88P"  888       "Y88P"                                            
+                                                                              
+"""
+
+banners['pypy2.7'] = """
+                                     .d8888b.      8888888888                 
+                                    d88P  Y88b           d88P                 
+                                           888          d88P                  
+88888b.  888  888 88888b.  888  888      .d88P         d88P                   
+888 "88b 888  888 888 "88b 888  888  .od888P"       88888888                  
+888  888 888  888 888  888 888  888 d88P"            d88P                     
+888 d88P Y88b 888 888 d88P Y88b 888 888"       d8b  d88P                      
+88888P"   "Y88888 88888P"   "Y88888 888888888  Y8P d88P                       
+888           888 888           888                                           
+888      Y8b d88P 888      Y8b d88P                                           
+888       "Y88P"  888       "Y88P"                                            
+                                                                              
+"""
