@@ -11,6 +11,7 @@ import collections.abc
 import sys
 
 from clu.constants.consts import STRINGPAIR, WHITESPACE, NoDefault
+from clu.config.abc import FlatOrderedSet as FOSet
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -86,8 +87,6 @@ class OrderedValuesView(collections.abc.ValuesView,
 
 # CHAINMAP: custom reprlib.Repr subclass
 
-typename = lambda thing: type(thing).__name__
-
 @export
 class ChainRepr(Repr):
     
@@ -116,25 +115,37 @@ class ChainRepr(Repr):
     def subrepr(self, thing, level):
         """ An internal “core” repr helper method. """
         from clu.typology import ismapping
+        
+        # For mappings, go down another level:
         if ischainmap(thing) or ismapping(thing):
             return self.repr1(thing, level - 1)
+        
+        # For everything else, defer to the type:
         return repr(thing)
     
     def primerepr(self, mapping, level):
         """ The internal method for “core” repr production
             of all ChainMaps, and related descendant types.
         """
+        # Special-case empty and single-item maps:
         if len(mapping) == 0:
             return "{}"
+        
         elif len(mapping) == 1:
             key = tuple(mapping.keys())[0]
             item = STRINGPAIR.format(key, self.subrepr(mapping[key], level))
             return f"{{ {item} }}"
+        
+        # Format all items:
         items = (STRINGPAIR.format(key, self.subrepr(mapping[key], level)) \
                                for key in mapping.keys())
+        
+        # Compute indentation levels:
         ts = "    " * (int(self.maxlevel - level) + 1)
         ls = "    " * (int(self.maxlevel - level) + 0)
         total = (f",\n{ts}").join(items)
+        
+        # Return the formatted map contents:
         return f"{{ \n{ts}{total}\n{ls}}}"
     
     def toprepr(self, chainmap, level):
@@ -146,21 +157,66 @@ class ChainRepr(Repr):
         from clu.naming import qualified_name
         from clu.testing.utils import multiple
         
-        tn = typename(chainmap)
+        # Typename and map item counts:
+        tn = qualified_name(type(chainmap))
         mapcount = len(chainmap.maps)
         keycount = len(chainmap)
+        
+        # Special-case empty maps:
+        if mapcount == 0 and keycount == 0:
+            ts = ls = total = ""
+            return f"{tn} «{mapcount} map{multiple(mapcount)}, " \
+                         f"{keycount} key{multiple(keycount)}» " \
+                         f"[{ts}{total}{ls}]"
+        
+        # Format all items:
         items = (STRINGPAIR.format(qualified_name(type(mapping)),
                                    self.primerepr(mapping, level - 1)) \
                                    for mapping in chainmap.maps)
+        
+        # Compute indentation levels:
         ts = "    " * (int(self.maxlevel - level) + 1)
         ls = "    " * (int(self.maxlevel - level) + 0)
         total = (f",\n{ts}").join(items)
+        
+        # Return all formatted sub-reprs:
         return f"{tn} «{mapcount} map{multiple(mapcount)}, " \
                      f"{keycount} key{multiple(keycount)}» " \
                      f"[\n{ts}{total}\n{ls}]"
     
+    def repr_dict(self, mapping, level):
+        return self.primerepr(mapping, level)
+    
+    def repr_UserDict(self, mapping, level):
+        return self.primerepr(mapping, level)
+    
+    def repr_Directory(self, mapping, level):
+        return mapping.inner_repr()
+    
+    def repr_TemporaryDirectory(self, mapping, level):
+        return mapping.inner_repr()
+    
+    def repr_SimpleNamespace(self, mapping, level):
+        return self.primerepr(asdict(mapping), level)
+    
+    def repr_Namespace(self, mapping, level):
+        return self.primerepr(asdict(mapping), level)
+    
+    def repr_defaultdict(self, mapping, level):
+        return self.primerepr(mapping, level)
+    
+    def repr_OrderedDict(self, mapping, level):
+        return self.primerepr(mapping, level)
+    
+    def repr_mappingproxy(self, mapping, level):
+        return self.primerepr(mapping, level)
+    
     def repr_ChainMap(self, chainmap, level):
-        # Handles both “clu.dict.ChainMap” and “collections.ChainMap”
+        # Handles both “clu.dict.ChainMap” and “collections.ChainMap”,
+        # thanks to “reprlib.Repr” name-based type dispatching:
+        return self.toprepr(chainmap, level)
+    
+    def repr_ChainMapPlusPlus(self, chainmap, level):
         return self.toprepr(chainmap, level)
     
     def shortrepr(self, thing):
@@ -199,6 +255,18 @@ class ChainMap(collections.abc.MutableMapping,
         """
         return cls((dict(iterable) for iterable in iterables), **overrides)
     
+    @classmethod
+    def is_a(cls, instance):
+        """ Check if an instance is a ChainMap of any sort – this covers:
+            
+            • this class (whichever it may be, derived or otherwise)
+            • the root clu.dicts.ChainMap type, and
+            • the original collections.ChainMap type as well.
+        """
+        return isinstance(instance, (cls,
+                                     ChainMap,
+                                     collections.ChainMap))
+    
     def __init__(self, *dicts, **overrides):
         """ Initialize a new ChainMap, using as many maps as specified as varargs,
             with any additional keyword args going into a new first map.
@@ -213,7 +281,7 @@ class ChainMap(collections.abc.MutableMapping,
         extras = [dict(**overrides)]
         maps = [] # type: list
         for d in dicts:
-            if isinstance(d, (type(self), collections.ChainMap)):
+            if type(self).is_a(d):
                 for map in d.maps:
                     if bool(map):
                         if map not in maps:
@@ -221,10 +289,10 @@ class ChainMap(collections.abc.MutableMapping,
             else:
                 if d not in maps:
                     maps.append(d)
-        if extras[0]:
+        if bool(extras[0]):
             self.maps = list(chain(maps, extras))
         else:
-            self.maps = list(maps) or extras
+            self.maps = maps
     
     def __missing__(self, key):
         raise KeyError(key)
@@ -267,14 +335,17 @@ class ChainMap(collections.abc.MutableMapping,
         return getitem(self, key, default=default)
     
     def mapchain(self):
+        """ Return a generator over all of the ChainMap’s mappings """
         yield from self.maps
     
     @property
     def top(self):
+        """ Return the first mapping – aka ``car(maps)`` """
         return self.maps[0]
     
     @property
     def rest(self):
+        """ Return all of the mappings behind the first – aka ``cdr(maps)`` """
         return self.maps[1:]
     
     def shift(self):
@@ -298,10 +369,7 @@ class ChainMap(collections.abc.MutableMapping,
             scene deleted from a kind of Pythonic Saw movie.
         """
         # Equivalent to collections.ChainMap.new_child(…)
-        cls = type(self)
-        if isinstance(map, (cls, collections.ChainMap)):
-            return cls(*(m for m in map.maps if bool(m)), *self.maps)
-        return cls(map or {}, *self.maps)
+        return type(self)(map or {}, *self.maps)
     
     def __setitem__(self, key, value):
         self.top[key] = value
@@ -309,8 +377,8 @@ class ChainMap(collections.abc.MutableMapping,
     def __delitem__(self, key):
         try:
             del self.top[key]
-        except KeyError:
-            raise KeyError(f'Key not found in the topmost mapping: {key!r}')
+        except KeyError as exc:
+            raise KeyError(f'Key not found in the topmost mapping: {key!r}') from exc
     
     def popitem(self):
         """ chainmap.popitem() → (key, value), remove & return a (key, value)
@@ -319,8 +387,8 @@ class ChainMap(collections.abc.MutableMapping,
         """
         try:
             return self.top.popitem()
-        except KeyError:
-            raise KeyError('No keys found in the topmost mapping')
+        except KeyError as exc:
+            raise KeyError('No keys found in the topmost mapping') from exc
     
     def pop(self, key, default=NoDefault):
         """ chainmap.pop(key[, default]) → v, remove specified “key” from
@@ -340,6 +408,14 @@ class ChainMap(collections.abc.MutableMapping,
         return self
     
     def mapcontaining(self, itx, default=NoDefault):
+        """ Search the ChainMap’s internal mappings for an item, by name,
+            and return the first mapping in which an item by this name
+            can be found.
+            
+            A default value, returned when no mappings are to be found
+            containing an item by the specified name, may optionally
+            be passsed in as well.
+        """
         from clu.predicates import finditem
         if default is NoDefault:
             return finditem(itx, *self.maps) or { itx : self.__missing__(itx) }
@@ -350,7 +426,6 @@ class ChainMap(collections.abc.MutableMapping,
             into a new, single, flat dictionary instance.
         """
         return merge_fast(*reversed(self.maps))
-        # return dict(iterchain(map.items() for map in self.maps))
     
     def clone(self, deep=False, memo=None):
         """ Return a cloned copy of the ChainMap instance """
@@ -362,6 +437,23 @@ class ChainMap(collections.abc.MutableMapping,
         return cls(deepcopy(self.top),
                  *(deepcopy(map) for map in self.rest))
 
+class ChainMapPlusPlus(ChainMap):
+    
+    def __init__(self, *dicts, **overrides):
+        
+        maps = []
+        
+        for d in dicts:
+            if type(self).is_a(d):
+                maps.append(FOSet(*d.maps, predicate=bool))
+            else:
+                maps.append(d)
+        
+        if bool(overrides):
+            maps.append(FOSet(dict(**overrides)))
+        
+        self.maps = FOSet(*maps)
+
 @export
 def ischainmap(thing):
     """ ischainmap(thing) → boolean predicate, True if the
@@ -483,7 +575,6 @@ def asdict(thing):
     from clu.typology import ismapping
     from clu.typespace.namespace import isnamespace
     if ischainmap(thing):
-        # return merge_fast(*reversed(thing.maps))
         return set(iterchain(thing.maps))
     if isnamespace(thing):
         return dict(thing.__dict__)
@@ -518,7 +609,8 @@ def test():
     from clu.constants.data import XDGS
     from clu.fs.filesystem import Directory
     from clu.predicates import try_items
-    from clu.testing.utils import inline, format_environment
+    from clu.testing.utils import inline
+    # from clu.testing.utils import format_environment
     import os
     
     stash = {}
@@ -588,7 +680,7 @@ def test():
             assert key in chainX
             
             # N.B. SLOW AS FUCK:
-            assert key in chain0.flatten()
+            # assert key in chain0.flatten()
             
             assert try_items(key, *chain0.maps, default=None) == try_items(key, *chainX.maps, default=None)
             assert try_items(key, *chain0.maps, default=None) == chain0[key]
@@ -598,17 +690,21 @@ def test():
     def test_three():
         """ Equality comparisons across the board """
         from clu.config.keymap import flatdict, Flat
+        from itertools import product
         
         chain0 = ChainMap(dict_arbitrary(),
-                           Flat(flatdict()))
+                          Flat(flatdict()))
         chain1 = chain0.clone()
         chainX = chain0.clone(deep=True)
+        chainZ = ChainMap(dict_arbitrary(),
+                          Flat(flatdict()))
         
-        assert chain0 == ChainMap(dict_arbitrary(),
-                                   Flat(flatdict()))
-        assert chain0 == chain1
-        assert chain0 == chainX
-        assert chainX == chain1
+        chains = (chain0, chain1, chainX, chainZ)
+        
+        # Assert that they’re all equal to one another:
+        for first, second in product(chains, chains):
+            if first is not second:
+                assert first == second
         
         print("REPR»CHAIN0:")
         print()
@@ -647,18 +743,71 @@ def test():
         
         repr_instance = ChainRepr()
         
-        assert repr_instance.repr(chain0) == repr_instance.repr(chainO)
+        print("REPR»CHAIN-OH:")
+        print()
+        print(repr_instance.repr(chainO))
+        print()
+    
+    @inline
+    def test_six_experimental():
+        """ Parity checks for experimental `ChainMapPlusPlus` """
+        chain0 = ChainMapPlusPlus(dict_arbitrary(),
+                                          fsdata(),
+                                     environment())
+        
+        chain1 = chain0.clone()
+        assert len(chain0) == len(chain1)
+        
+        for key in chain0.keys():
+            assert key in chain0
+            assert key in chain1
+            
+            # N.B. SLOW AS FUCK:
+            # assert key in chain0.flatten()
+            
+            assert try_items(key, *chain0.maps, default=None) == try_items(key, *chain1.maps, default=None)
+            assert try_items(key, *chain0.maps, default=None) == chain0[key]
+            assert try_items(key, *chain0.maps, default=None) == chain1[key]
+    
+    @inline
+    def test_seven_experimental():
+        """ Equality comparisons with `ChainMapPlusPlus` """
+        from clu.config.keymap import flatdict, Flat
+        from itertools import product
+        
+        chain0 = ChainMapPlusPlus(dict_arbitrary(),
+                                  Flat(flatdict()))
+        chain1 = chain0.clone()
+        chainX = chain0.clone(deep=True)
+        
+        chain00 = ChainMap(dict_arbitrary(),
+                           Flat(flatdict()))
+        chain11 = chain00.clone()
+        chainXX = chain00.clone(deep=True)
+        
+        pp = (chain0,  chain1,  chainX)
+        cm = (chain00, chain11, chainXX)
+        
+        # Assert that they’re all equal to one another:
+        for first, second in product(pp+cm, cm+pp):
+            if first is not second:
+                assert first == second
+        
+        print("REPR»CHAIN0:")
+        print()
+        print(repr(chain0))
+        print()
     
     @inline.diagnostic
     def restore_environment():
         """ Restore environment from stashed values """
         os.environ = stash
     
-    @inline.diagnostic
-    def show_environment():
-        """ Show environment variables """
-        for envline in format_environment():
-            print(envline)
+    # @inline.diagnostic
+    # def show_environment():
+    #     """ Show environment variables """
+    #     for envline in format_environment():
+    #         print(envline)
     
     # Run all inline tests, return POSIX status
     return inline.test(100)
