@@ -10,6 +10,7 @@ iterchain = chain.from_iterable
 dataclass = dataclass_fn(repr=False)
 
 import abc
+import collections.abc
 import clu.abstract
 import clu.dicts
 import importlib
@@ -31,20 +32,25 @@ except ImportError:
 from clu.constants import consts
 from clu.extending import Extensible
 from clu.naming import nameof, dotpath_split, dotpath_join, qualified_name
-from clu.predicates import anyattrs, attr, attr_search, item_search, mro, tuplize
-from clu.repr import stringify
+
+from clu.predicates import (anyattrs, attr,
+                            attr_search, item_search,
+                            mro, none_function, tuplize)
+
+from clu.repr import stringify, hexid
 from clu.typespace import types
 from clu.typology import ismodule, ismapping, isstring, subclasscheck
 from clu.exporting import Registry as ExporterRegistry
-from clu.exporting import ExporterBase, Exporter
+from clu.exporting import ExporterBase, Exporter, thismodule
 
 NoDefault = consts.NoDefault
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
-# The module-subclass registry dictionary:
+# The module-subclass and loader-subclass registry dictionaries:
 monomers = DefaultDict(weakref.WeakValueDictionary)
+linkages = weakref.WeakValueDictionary()
 
 class MetaRegistry(Extensible):
     
@@ -121,6 +127,18 @@ def all_registered_modules():
     """ Return a generator over the instances of all registered class-based modules """
     yield from iterchain(modules.values() for modules in Registry.monomers.values())
 
+# Given a qualified name e.g. “clu.app.Module”, extract the appspace (“app” in the example):
+get_appspace = lambda string: string.rpartition(consts.QUALIFIER)[0].partition(consts.QUALIFIER)[-1]
+
+@export
+def all_registered_appspaces():
+    """ Return a generator of strings listing all registered “appspaces” """
+    yield from frozenset(
+               filter(None,
+               map(get_appspace,
+               iterchain(modules.keys() \
+                     for modules in Registry.monomers.values()))))
+
 @export
 def modules_for_appname(appname):
     """ Return a generator over the instances of an apps’ registered class-based modules """
@@ -137,6 +155,14 @@ def modules_for_appname(appname):
     except RuntimeError:
         yield from modules.values()
 
+@export
+def appspaces_for_appname(appname):
+    """ Return a generator over the “appspaces” belonging to a given registered app """
+    modules = Registry.monomers.get(appname, {})
+    yield from frozenset(
+               filter(None,
+               map(get_appspace, modules.keys())))
+
 @export
 class Registry(abc.ABC, metaclass=MetaRegistry):
     
@@ -159,10 +185,6 @@ class Registry(abc.ABC, metaclass=MetaRegistry):
             # Register this subclass if the names are good:
             if cls.qualname not in Registry.monomers[cls.appname]:
                 Registry.monomers[cls.appname][cls.qualname] = cls
-            # Register the root class for this subclass,
-            # also name-wellness permitting:
-            # if cls.prefix not in Registry.monomers[cls.appname]:
-            #     Registry.monomers[cls.appname][cls.qualname] = ???
     
     @classmethod
     def __class_getitem__(cls, key):
@@ -235,79 +257,74 @@ class MetaTypeRepr(abc.ABCMeta):
         return f"<class “{qualname}” from “{appname}”>"
 
 @export
-class FinderBase(clu.abstract.AppName,
-                 importlib.abc.MetaPathFinder,
-                 metaclass=MetaTypeRepr):
+class ArgumentSink(collections.abc.Callable,
+                   collections.abc.Hashable,
+                   clu.abstract.ReprWrapper,
+                   metaclass=MetaTypeRepr):
     
-    """ The base class for all class-based module finders.
+    """ ArgumentSink is a class that stores the arguments with
+        which it is initialized, for either later retrieval or
+        subsequent functional application.
         
-        One must subclass this class once per app, specifying
-        an “appname” – the name of the app. Q.v. the function
-        “initialize_types(…)” sub. to easily set these up for
-        your own app.
+        To wit:
         
-        The class method “FinderBase.find_spec(…)” caches its
-        returned instances of “ModuleSpec” using a ‘zict.LRU’
-        buffer, which is shared across all of the installed
-        “FinderBase” subclasses – meaning that if a spec has
-        been cached for one installed app via this mechanism,
-        it will be found by the first Finder subclass that
-        shows up in “sys.meta_path” to field a query for it (!)
+            >>> sink = ArgumentSink('yo', 'dogg', iheard="you like")
+            >>> assert sink.args == ('yo', 'dogg')
+            >>> assert sink.kwargs == dict(iheard="you like")
+            >>> sink(stringify) # prints “str(iheard=you like) @ 0x10bd”
     """
+    __slots__ = ('args', 'kwargs')
     
-    specs = {}
-    cache = zict.LRU(64, specs)
-    
-    @classmethod
-    def spec(cls, fullname):
-        out = cls.cache[fullname] = ModuleSpec(fullname, cls.loader)
-        return out
-    
-    @classmethod
-    def find_spec(cls, fullname, path=None, target=None):
-        """ Return a ModuleSpec for a qualified module name –
-            creating an instance anew if necessary, and returning
-            an existing one from the cache if available.
+    def __new__(cls, *args, **kwargs):
+        """ Create a new ArgumentSink, with arbitrary positional
+            and/or keyword arguments
         """
-        if fullname in cls.cache:
-            return cls.cache[fullname]
-        if consts.QUALIFIER not in fullname:
-            if fullname == cls.appname:
-                return cls.spec(fullname)
-            return None
-        appname, appspace, *remainders = fullname.split(consts.QUALIFIER, 2)
-        if appname == cls.appname and appspace in polymers.all_appspaces():
-            return cls.spec(fullname)
-        return None
+        instance = super().__new__(cls)
+        instance.args = args
+        instance.kwargs = kwargs
+        return instance
     
-    @classmethod
-    def invalidate_caches(cls):
-        """ Clear both the Finder’s internal ModuleSpec instance
-            cache, and its associated Loader instances’ memoization
-            cache for the “create_module(…)” method (q.v. method
-            implementation sub.)
+    def __call__(self, function):
+        """ Apply the sinks’ arguments to a function – or, indeed,
+            any callable – returning the result
         """
-        cls.loader.create_module.cache_clear()
-        cls.cache.clear()
-        return None
+        return function(*self.args, **self.kwargs)
     
-    @classmethod
-    def iter_modules(cls):
-        """ This “non-standard API method”§ yields ‘pkgutil.ModuleInfo’
-            instances for each registered class-module in the finder
-            subclasses’ given app.
-            
-            § q.v. boxed notation sub., Python documentation,
-              https://docs.python.org/3/library/pkgutil.html#pkgutil.iter_modules
-        """
-        yield from (pkgutil.ModuleInfo(cls, module.qualname, ispkg=False) \
-                                        for module \
-                                         in modules_for_appname(cls.appname))
+    def __hash__(self):
+        return hash(frozenset(self.args)) \
+             & hash(frozenset(self.kwargs.items()))
+    
+    def inner_repr(self):
+        return f"args=“{self.args!r}”, kwargs=“{self.kwargs!r}”"
+    
+    def __eq__(self, other):
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        return self.args   == other.args \
+           and self.kwargs == other.kwargs
+    
+    def __ne__(self, other):
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        return self.args   != other.args \
+            or self.kwargs != other.kwargs
+
+class MetaNameAndSpaces(MetaTypeRepr):
+    
+    """ A metaclass that adds an “appspaces” iterable class property """
+    
+    @property
+    def appspaces(cls):
+        appname = getattr(cls, 'appname', None)
+        if appname is not None:
+            yield from appspaces_for_appname(appname)
+        else:
+            yield from tuple()
 
 @export
 class LoaderBase(clu.abstract.AppName,
                  importlib.abc.Loader,
-                 metaclass=MetaTypeRepr):
+                 metaclass=MetaNameAndSpaces):
     
     """ The base class for all class-based module loaders.
         
@@ -321,14 +338,51 @@ class LoaderBase(clu.abstract.AppName,
         function decorator.
     """
     
+    @classmethod
+    def __init_subclass__(cls, **kwargs):
+        """ Initialize a new LoaderBase subclass, registering it
+            if it proves to possess a unique “appname” string.
+        """
+        super().__init_subclass__(**kwargs)
+        appname = getattr(cls, 'appname', None)
+        if appname:
+            if appname not in linkages:
+                linkages[appname] = cls
+        cls.instances = weakref.WeakValueDictionary()
+    
+    def __new__(cls, *args, **kwargs):
+        """ Create a new Loader instance.
+            
+            N.B. no initialization arguments are necessary.
+        """
+        # Create an ArgumentSink matching the loader’s
+        # initialization arguments:
+        key = ArgumentSink(*args, **kwargs)
+        
+        # If a loader already matches these arguments,
+        # return it immediately:
+        if key in cls.instances:
+            return cls.instances[key]
+        
+        # Create and register a new loader, as per the
+        # arguments with which to initialize this new
+        # loader instance:
+        try:
+            cls.instances[key] = instance = super().__new__(cls, *args, **kwargs)
+        except TypeError:
+            cls.instances[key] = instance = super().__new__(cls)
+        
+        # Return the newly created instance:
+        return instance
+    
     @staticmethod
     def package_module(name):
-        """ Convenience method, returning an empty package module """
+        """ Convenience method, returning an empty package module. """
         return Package(name, f"Package (filler) module {name}")
     
     @cache
     def create_module(self, spec):
-        """ Create a new class-based module from a spec instance """
+        """ Create a new class-based module from a spec instance. """
         cls = type(self)
         if Registry.has_appname(cls.appname):
             if spec.name in Registry[cls.appname]:
@@ -341,7 +395,7 @@ class LoaderBase(clu.abstract.AppName,
                 if spec.name == cls.appname:
                     return self.package_module(spec.name)
                 appname, appspace, *remainders = spec.name.split(consts.QUALIFIER, 2)
-                if appname == cls.appname and appspace in polymers.all_appspaces():
+                if appname == cls.appname and appspace in cls.appspaces:
                     return self.package_module(spec.name)
             return None
         return None
@@ -379,42 +433,97 @@ class LoaderBase(clu.abstract.AppName,
                 tuplize(type(self).appname))
     
     def __repr__(self):
-        qualname = qualified_name(self)
+        location = hexid(self)
+        qualname = qualified_name(type(self))
         appname = getattr(self, 'appname', None)
         if appname is None:
-            return f"<loader “{qualname}”>"
-        return f"<loader “{qualname}” from “{appname}”>"
+            return f"<loader “{qualname}” {consts.REPR_DELIMITER} {location}>"
+        return f"<loader “{qualname}” from “{appname}” {consts.REPR_DELIMITER} {location}>"
 
 @export
-class ArgumentSink(object):
+class FinderBase(clu.abstract.AppName,
+                 importlib.abc.MetaPathFinder,
+                 metaclass=MetaNameAndSpaces):
     
-    """ ArgumentSink is a class that stores the arguments with
-        which it is initialized, for either later retrieval or
-        subsequent functional application.
+    """ The base class for all class-based module finders.
         
-        To wit:
+        One must subclass this class once per app, specifying
+        an “appname” – the name of the app. Q.v. the function
+        “initialize_types(…)” sub. to easily set these up for
+        your own app.
         
-            >>> sink = ArgumentSink('yo', 'dogg', iheard="you like")
-            >>> assert sink.args == ('yo', 'dogg')
-            >>> assert sink.kwargs == dict(iheard="you like")
-            >>> sink(stringify) # prints “str(iheard=you like) @ 0x10bd”
+        The class method “FinderBase.find_spec(…)” caches its
+        returned instances of “ModuleSpec” using a ‘zict.LRU’
+        buffer, which is shared across all of the installed
+        “FinderBase” subclasses – meaning that if a spec has
+        been cached for one installed app via this mechanism,
+        it will be found by the first Finder subclass that
+        shows up in “sys.meta_path” to field a query for it (!)
     """
-    __slots__ = ('args', 'kwargs')
     
-    def __new__(cls, *args, **kwargs):
-        """ Create a new ArgumentSink, with arbitrary positional
-            and/or keyword arguments
-        """
-        instance = object.__new__(cls)
-        instance.args = args
-        instance.kwargs = kwargs
-        return instance
+    specs = {}
+    cache = zict.LRU(64, specs)
     
-    def __call__(self, function):
-        """ Apply the sinks’ arguments to a function – or, indeed,
-            any callable – returning the result
+    @classmethod
+    def __init_subclass__(cls, **kwargs):
+        """ Initialize a new FinderBase subclass – assigning to it
+            a loader class, and an instance of same, corresponding
+            to the “appname” string of this new FinderBase subclass.
         """
-        return function(*self.args, **self.kwargs)
+        super().__init_subclass__(**kwargs)
+        appname = getattr(cls, 'appname', None)
+        cls.__loader__ = linkages.get(appname, none_function)
+        cls.loader = cls.__loader__()
+    
+    @classmethod
+    def spec(cls, fullname):
+        """ Create, cache, and return a new ModuleSpec, corresponding
+            to a given dotpath (née “fullname”) and using the Finder’s
+            embedded loader instance.
+        """
+        out = cls.cache[fullname] = ModuleSpec(fullname, cls.loader)
+        return out
+    
+    @classmethod
+    def find_spec(cls, fullname, path=None, target=None):
+        """ Return a ModuleSpec for a qualified module name –
+            creating an instance anew if necessary, and returning
+            an existing one from the cache if available.
+        """
+        if fullname in cls.cache:
+            return cls.cache[fullname]
+        if consts.QUALIFIER not in fullname:
+            if fullname == cls.appname:
+                return cls.spec(fullname)
+            return None
+        appname, appspace, *remainders = fullname.split(consts.QUALIFIER, 2)
+        if appname == cls.appname and appspace in cls.appspaces:
+            return cls.spec(fullname)
+        return None
+    
+    @classmethod
+    def invalidate_caches(cls):
+        """ Clear both the Finder’s internal ModuleSpec instance
+            cache, and its associated Loader instances’ memoization
+            cache for the “create_module(…)” method (q.v. method
+            implementation sub.)
+        """
+        cls.loader.create_module.cache_clear()
+        cls.cache.clear()
+        return None
+    
+    @classmethod
+    def iter_modules(cls):
+        """ This “non-standard API method”§ yields ‘pkgutil.ModuleInfo’
+            instances for each registered class-module in the finder
+            subclasses’ given app.
+            
+            § q.v. boxed notation sub., Python documentation,
+              https://docs.python.org/3/library/pkgutil.html#pkgutil.iter_modules
+        """
+        yield from (pkgutil.ModuleInfo(cls, module.qualname, ispkg=False) \
+                                        for module \
+                                         in modules_for_appname(cls.appname))
 
 class MetaModule(MetaRegistry):
     
@@ -512,7 +621,9 @@ class MetaModule(MetaRegistry):
         return cls
 
 @export
-class ModuleAlias(object):
+class ModuleAlias(collections.abc.Hashable,
+                  clu.abstract.ReprWrapper,
+                  metaclass=MetaTypeRepr):
     
     """ A ModuleAlias is created when subscripting the ModuleBase
         type, or a subtype thereof, with another ModuleBase subtype,
@@ -525,17 +636,38 @@ class ModuleAlias(object):
     __slots__ = ('origin', 'specializer')
     
     def __init__(self, origin, specializer):
+        """ Initialize a ModuleAlias, with an origin class and a specializer type """
         if not issubclass(origin, ModuleBase):
             raise TypeError('Specialization requires a Module type')
-        if not issubclass(specializer, ModuleBase):
-            raise TypeError('Specialization requires a Module type')
+        if specializer is not None:
+            if not issubclass(specializer, ModuleBase):
+                raise TypeError('Specialization requires a Module type')
         self.origin = origin 
         self.specializer = specializer
     
+    def __hash__(self):
+        return hash(self.origin) \
+             & hash(self.specializer)
+    
     def __mro_entries__(self, bases):
         return tuplize(self.origin,
                        self.specializer)
-
+    
+    def inner_repr(self):
+        return f"origin=“{self.origin!r}”, specializer=“{self.specializer!r}”"
+    
+    def __eq__(self, other):
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        return self.origin      == other.origin \
+           and self.specializer == other.specializer
+    
+    def __ne__(self, other):
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        return self.origin      != other.origin \
+            or self.specializer != other.specializer
+    
 DO_NOT_INCLUDE = { '__abstractmethods__',
                    '__execute__',
                    '_abc_impl', '_executed', 'monomers' }
@@ -563,9 +695,11 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
         even bother with ’em.
     """
     
-    # The appname and appspace default to None:
+    # The ‘appname’, ‘appspace’, and ‘__loader__’ class attributes
+    # all default to None:
     appname = None
     appspace = None
+    __loader__ = None
     
     # Block access to the registry’s underlying data:
     monomers = clu.abstract.ValueDescriptor({})
@@ -578,6 +712,7 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
         ancestors = mro(cls)
         cls.appname  = appname  or attr_search('appname',  *ancestors)
         cls.appspace = appspace or attr_search('appspace', *ancestors)
+        cls.__loader__ = linkages.get(cls.appname, none_function)()
         super(ModuleBase, cls).__init_subclass__(**kwargs)
     
     @classmethod
@@ -733,33 +868,33 @@ def installed_appnames():
             appnames.add(finder.appname)
     return appnames
 
-def initialize_module(appname, appspace, loader):
+def initialize_module(appname, appspace, module):
     """ Private helper for “initialize_types(…)” """
     
-    class Module(ModuleBase, appname=appname,
-                             appspace=appspace):
-        __loader__ = loader
+    class Module(ModuleBase,
+                 appname=appname,
+                 appspace=appspace):
+        __module__ = module
     
     return Module
 
-def initialize_new_types(appname, appspace):
+def initialize_new_types(appname, appspace, module):
     """ Private helper for “initialize_types(…)” """
     
-    class Loader(LoaderBase, appname=appname):
-        pass
+    class Loader(LoaderBase,
+                 appname=appname):
+        __module__ = module
     
-    class Finder(FinderBase, appname=appname):
-        __loader__ = Loader
-        loader = Loader()
+    class Finder(FinderBase,
+                 appname=appname):
+        __module__ = module
     
-    Module = initialize_module(appname,
-                               appspace,
-                               Finder.loader)
+    Module = initialize_module(appname, appspace, module)
     
     return Module, Finder, Loader
 
 @export
-def initialize_types(appname, appspace='app'):
+def initialize_types(appname, appspace=consts.DEFAULT_APPSPACE):
     """ Initialize subtypes of FinderBase, LoaderBase, and ModuleBase,
         configured for a specific “appname” and “appspace” (the latter
         of which defaults to ‘app’).
@@ -778,7 +913,9 @@ def initialize_types(appname, appspace='app'):
         perapp = polymers[appname]
     
     except KeyError:
-        Module, Finder, Loader = initialize_new_types(appname, appspace)
+        Module, Finder, Loader = initialize_new_types(appname,
+                                                      appspace,
+                                                      module=thismodule())
         polymers.store(appname, loader=Loader,
                                 finder=Finder,
                         **{ appspace : Module })
@@ -789,7 +926,9 @@ def initialize_types(appname, appspace='app'):
         Module = perapp.modules.get(appspace, None)
         
         if Module is None:
-            Module = initialize_module(appname, appspace, perapp.finder.loader)
+            Module = initialize_module(appname,
+                                       appspace,
+                                       module=thismodule())
             polymers.add_module(appname=appname,
                                appspace=appspace,
                                  module=Module)
@@ -933,7 +1072,7 @@ class ProxyModule(ModuleBase):
         (as above) – like so:
             
             >>> Module, Finder, Loader = initialize_types(my_appname)
-            >>> class MyProxy(ProxyModule[Module]):
+            >>> class myproxy(ProxyModule[Module]):
             >>>     # …etc
         
         Here’s a basic example of a ProxyModule subtype definition:
@@ -1031,7 +1170,11 @@ class ProxyModule(ModuleBase):
                 # how module “__init__(…)” methods are nondeterministically
                 # subject to being called more than once:
                 setattr(cls, '_targets', attr(cls, 'targets', '_targets'))
-                delattr(cls, 'targets')
+                try:
+                    # Fails when “targets” is a superclass attribute:
+                    delattr(cls, 'targets')
+                except AttributeError:
+                    pass
     
     def __execute__(self):
         # Create the internal “clu.dicts.ChainMap” subclass instance,
@@ -1070,9 +1213,11 @@ class ProxyModule(ModuleBase):
             typename = type(self).__name__
             raise AttributeError(f"‘{typename}’ access failure for «{key}»") from exc
 
-export(Module, name='Module')
-export(Finder, name='Finder')
-export(Loader, name='Loader')
+export(Module,          name='Module')
+export(Finder,          name='Finder')
+export(Loader,          name='Loader')
+
+export(get_appspace,    name='get_appspace',    doc="get_appspace(string) → Given a qualified name e.g. “clu.app.Module”, extract the appspace (“app” in the example)")
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
@@ -1081,12 +1226,40 @@ def test():
     
     from clu.testing.utils import inline
     from pprint import pprint, pformat
+    from clu.naming import moduleof
     
     @inline.precheck
     def show_python_executable():
         """ Show the Python executable """
         print("PYTHON:", sys.executable)
     
+    @inline.precheck
+    def show_module_from_frame():
+        """ Use `inspect.currentframe()` to find the parent module """
+        parentframe = inspect.currentframe().f_back.f_back.f_back
+        parentname = parentframe.f_code.co_name
+        module = inspect.getmodule(parentframe)
+        print("Frame:", parentframe)
+        print("name:", parentname)
+        print("module:", module)
+        print("module name:", nameof(module))
+        print("qualified module name:", qualified_name(module))
+        print("module of module:", moduleof(module))
+    
+    @inline.precheck
+    def show_module_wtf_hax():
+        def mod():
+            lam = lambda: None
+            return moduleof(lam)
+        print("module:", mod())
+    
+    @inline.precheck
+    def show_module_fucking_seriously():
+        from clu.exporting import thismodule
+        module_from = globals().get('exporter', ExporterBase()).dotpath
+        print("module from:", module_from)
+        print("module():", thismodule())
+    
     @inline
     def test_one():
         """ Class-module basics """
@@ -1094,7 +1267,7 @@ def test():
         m = Module(consts.APPNAME)
         assert m
         assert m.appname == consts.APPNAME
-        assert m.appspace == 'app'
+        assert m.appspace == consts.DEFAULT_APPSPACE
         assert m.__name__ == 'clu.app.clu'
         assert nameof(m) == consts.APPNAME
     
@@ -1145,7 +1318,7 @@ def test():
             pass
         
         assert m.appname == consts.APPNAME
-        assert m.appspace == 'app'
+        assert m.appspace == consts.DEFAULT_APPSPACE
         assert m.__name__ == 'clu.app.clu'
         assert nameof(m) == consts.APPNAME
         
@@ -1269,6 +1442,35 @@ def test():
         assert not hasattr(overridden, 'target_dicts')  # lowercase: fallback raises KeyError
         assert hasattr(overridden, '_targets')          # attribute found normally
     
+    @inline
+    def test_five_point_eight():
+        """ Proxy-module hybrid definition check """
+        
+        overrides = dict(APPNAME='yodogg',
+                         PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
+                         BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
+        
+        # Ensure that the definitions in the class-module itself
+        # take precedent over all proxied target items:
+        class TestOverrideConstsHybridProxy(ProxyModule[Module]):
+            targets = (overrides, consts)
+            
+            APPNAME = 'DOGG-YO'
+            BASEPATH = consts.BASEPATH
+        
+        from clu.app import TestOverrideConstsHybridProxy as overridden
+        
+        assert overridden.USER == consts.USER                   # value from “consts” target
+        assert overridden.BUILTINS == consts.BUILTINS           # value from “consts” target
+        assert overridden.BASEPATH == consts.BASEPATH           # value from class-module
+        assert overridden.APPNAME == 'DOGG-YO'                  # value from class-module
+        assert str(overridden.PROJECT_PATH).endswith('yodogg')  # value from “overrides” target
+        assert not str(overridden.BASEPATH).endswith('yodogg')  # NOT the value from “overrides”
+        
+        assert not hasattr(overridden, 'targets')
+        assert not hasattr(overridden, 'target_dicts')
+        assert hasattr(overridden, '_targets')
+        
     @inline
     def test_six():
         """ Polymer-type caching and “initialize_types(…)” checks """
@@ -1333,7 +1535,7 @@ def test():
         
         for specname in sorted(FinderBase.specs.keys()):
             spec = FinderBase.specs[specname]
-            string = pformat(spec.__dict__, indent=4)
+            string = pformat(spec.__dict__, indent=4, width=consts.SEPARATOR_WIDTH)
             cached = getattr(spec, 'cached', None)
             hasloc = getattr(spec, 'has_location', None)
             parent = getattr(spec, 'parent', None)
@@ -1356,11 +1558,30 @@ def test():
             monos = dict(monomers[appname])
             monocount = len(monos)
             monoplural = (monocount == 1) and "monomer" or "monomers"
-            string = pformat(monos, indent=4)
+            string = pformat(monos, indent=4, width=consts.SEPARATOR_WIDTH)
             print()
             print(f"    «{appname}» ({monocount} {monoplural}):")
             print(f"{string}")
     
+    @inline.diagnostic
+    def show_linkages():
+        """ Show all registered Loader subclasses """
+        appnames = tuple(linkages.keys())
+        appcount = len(appnames)
+        plural = (appcount == 1) and "app" or "apps"
+        print(f"LINKAGES ({appcount} {plural} total):")
+        
+        for appname in appnames:
+            LoaderCls = linkages[appname]
+            qname = qualified_name(LoaderCls)
+            instancedict = dict(LoaderCls.instances)
+            instancecount = len(LoaderCls.instances)
+            instanceplural = (instancecount == 1) and "instance" or "instances"
+            string = pformat(instancedict, indent=4, width=consts.SEPARATOR_WIDTH)
+            print()
+            print(f"    «{appname}» ({qname}, {instancecount} {instanceplural}):")
+            print(f"{string}")
+    
     @inline.diagnostic
     def show_polymers():
         """ Show per-app class-module-related subclasses """
@@ -1373,7 +1594,7 @@ def test():
             perapp = polymers[appname]
             modcount = len(perapp.modules)
             modplural = (modcount == 1) and "module" or "modules"
-            string = pformat(perapp.__dict__, indent=4)
+            string = pformat(perapp.__dict__, indent=4, width=consts.SEPARATOR_WIDTH)
             print()
             print(f"    «{appname}» ({modcount} {modplural}):")
             print(f"{string}")
