@@ -10,6 +10,11 @@ nox.options.keywords = "not codecov"
 nox.options.reuse_existing_virtualenvs = True
 nox.options.stop_on_first_error = True
 
+# Skip manifest check if we’re not running in a Git repo:
+from clu.version.git_version import are_we_gitted
+if not are_we_gitted():
+    nox.options.keywords += " and not checkmanifest"
+
 @nox.session
 def checkmanifest(session):
     """ Check CLU’s MANIFEST.in against the Git HEAD """
@@ -18,14 +23,17 @@ def checkmanifest(session):
 
 @nox.session
 @nox.parametrize('module', (
-    nox.param('clu.constants',  id='consts'),
-    nox.param('clu',            id='modules'),
-    nox.param('clu.version',    id='version')))
+    nox.param('clu.constants',    id='consts'),
+    nox.param('clu',              id='modules'),
+    nox.param('clu.version',      id='version'),
+    nox.param('clu.scripts.repl', id='repl')))
 def checkmodule(session, module):
-    """ Show CLU consts, modules, or versioning """
+    """ Check CLU consts, modules, REPL, or versioning """
     session.install("-r", "requirements/install.txt")
     if module == 'clu':
         session.install("-r", "requirements/nox/tests.txt")
+    elif module == 'clu.scripts.repl':
+        session.install("-r", "requirements/nox/repl.txt")
     session.run('python', '-m', module)
 
 @nox.session
@@ -34,7 +42,7 @@ def pytest(session):
     session.env['MACOSX_DEPLOYMENT_TARGET']         = '10.14'
     session.env['PYTEST_DISABLE_PLUGIN_AUTOLOAD']   = '1'
     session.install("-r", "requirements/install.txt")
-    session.install("-r", "requirements/nox/tests.txt")
+    session.install("-r", "requirements/nox/repl.txt")
     session.run('pytest')
 
 def parametrized_inline_tests():
@@ -58,7 +66,7 @@ def codecov(session):
     session.env['MACOSX_DEPLOYMENT_TARGET']         = '10.14'
     session.env['PYTEST_DISABLE_PLUGIN_AUTOLOAD']   = '1'
     session.install("-r", "requirements/install.txt")
-    session.install("-r", "requirements/nox/tests.txt")
+    session.install("-r", "requirements/nox/repl.txt")
     session.install("-r", "requirements/nox/codecov.txt")
     session.run('pytest', '-p', 'pytest_cov', '--cov=clu',
                                               '--cov-report=xml:coverage.xml',
